@@ -245,7 +245,7 @@ def test_cpp_failure_repr(dummy_failure):
 def test_cpp_files_option(testdir, exes):
     exes.get('boost_success')
     exes.get('gtest')
-    
+
     result = testdir.inline_run('--collect-only')
     reps = result.getreports()
     assert len(reps) == 1
@@ -260,6 +260,99 @@ def test_cpp_files_option(testdir, exes):
     assert len(result.matchreport(exes.exe_name('gtest')).result) == 4
 
 
+def test_google_one_argument(testdir, exes):
+    testdir.makeini('''
+        [pytest]
+        cpp_arguments = argument1
+    ''')
+
+    result = testdir.inline_run(exes.get('gtest_args'),
+                                '-k',
+                                'ArgsTest.one_argument')
+    assert_outcomes(result,
+                    [('ArgsTest.one_argument', 'passed')])
+
+
+def test_google_two_arguments(testdir, exes):
+    testdir.makeini('''
+        [pytest]
+        cpp_arguments = argument1 argument2
+    ''')
+
+    result = testdir.inline_run(exes.get('gtest_args'),
+                                '-k',
+                                'ArgsTest.two_arguments')
+    assert_outcomes(result,
+                    [('ArgsTest.two_arguments', 'passed')])
+
+
+def test_google_one_argument_via_option(testdir, exes):
+    result = testdir.inline_run(exes.get('gtest_args'),
+                                '-k',
+                                'ArgsTest.one_argument',
+                                '-o', 'cpp_arguments=argument1')
+    assert_outcomes(result,
+                    [('ArgsTest.one_argument', 'passed')])
+
+
+def test_google_two_arguments_via_option(testdir, exes):
+    result = testdir.inline_run(exes.get('gtest_args'),
+                                '-k',
+                                'ArgsTest.two_arguments',
+                                '-o', 'cpp_arguments=argument1 argument2')
+    assert_outcomes(result,
+                    [('ArgsTest.two_arguments', 'passed')])
+
+
+def test_argument_option_priority(testdir, exes):
+    testdir.makeini('''
+        [pytest]
+        cpp_arguments = argument2
+    ''')
+    result = testdir.inline_run(exes.get('gtest_args'),
+                                '-k',
+                                'ArgsTest.one_argument',
+                                '-o', 'cpp_arguments=argument1')
+    assert_outcomes(result,
+                    [('ArgsTest.one_argument', 'passed')])
+
+
+def test_boost_one_argument(testdir, exes):
+    testdir.makeini('''
+        [pytest]
+        cpp_arguments = argument1
+    ''')
+
+    result = testdir.inline_run(exes.get('boost_one_argument'))
+    assert_outcomes(result,
+                    [('boost_one_argument', 'passed')])
+
+
+def test_boost_two_arguments(testdir, exes):
+    testdir.makeini('''
+        [pytest]
+        cpp_arguments = argument1 argument2
+    ''')
+
+    result = testdir.inline_run(exes.get('boost_two_arguments'))
+    assert_outcomes(result,
+                    [('boost_two_arguments', 'passed')])
+
+
+def test_boost_one_argument_via_option(testdir, exes):
+    result = testdir.inline_run(exes.get('boost_one_argument'),
+                                '-o', 'cpp_arguments=argument1')
+    assert_outcomes(result,
+                    [('boost_one_argument', 'passed')])
+
+
+def test_boost_two_arguments_via_option(testdir, exes):
+    result = testdir.inline_run(exes.get('boost_two_arguments'),
+                                '-o', 'cpp_arguments=argument1 argument2')
+    assert_outcomes(result,
+                    [('boost_two_arguments', 'passed')])
+
+
 def test_passing_files_directly_in_command_line(testdir, exes):
     f = exes.get('boost_success')
     result = testdir.runpytest(f)
